uno-cli-0.1.5 is not a library.

Uno-CLI
Install
With Cargo Installed
$ cargo install uno-cli
Building from Source
$ git clone https://github.com/benraz123/uno
$ cd uno
$ cargo run
What is this?
uno-cli is an attempt to model Uno in a command line context.
How does Uno-CLI work?
To launch, write uno-cli. Use WASD/HJKL keys to select cards. A card can be played if it is a wild card, or if it is the same number or same color or both.
Default Keybindings
| Key | Action |
|---|---|
| a / h | Move cursor one to the left |
| d / l | Move cursor one to the right |
| Enter | Select Option |